/* vim: set sw=8 ts=8 si et: */
/*************************************************************************
Title:    lcd display test software
Author:   guido socher 
Copyright: GPL
**************************************************************************/

#include <avr/io.h>
#include <avr/pgmspace.h>
#include <avr/interrupt.h>
#define F_CPU 1000000UL  // 1 MHz
#include <util/delay.h>

#include <string.h>
#include <stdlib.h>
#include "lcd.h"        /* these are the prototypes and defines for lcd.c */

/* should be longer than the length of the banner string, see also ROLLLEN in lcd.h*/
#define BANNERSCROLLEN 16

#define LEDOUT PORTC5
#define LEDPORT PORTC
#define LEDDDR DDRC
#define LEDDDRPIN DDC5

/* enable pin as output: */
#define LED_INIT LEDDDR|=(1<<LEDDDRPIN)
#define LEDON LEDPORT&=~(1<<LEDOUT)
#define LEDOFF LEDPORT|=(1<<LEDOUT)

// _delay_ms uses a floating point datatype if you call
// that function in many places in your code then it becomes
// very fat. An integer is enough for us:
//
// delay x milliseconds:
void delay_ms(unsigned int xms)
{
        while(xms){
                _delay_ms(0.96);
                xms--;
        }
}


int main(void)
{
        char *banner = (char *)PSTR("tuxgraphics");
#ifdef FRENCH
        char french[] = {'a','s','-','t','u',' ','d',0xe9,'j',0xe0,' ','v','u','?',0};
#endif
        unsigned char i;


        /* initialize display, cursor off */
        lcd_init(LCD_DISP_ON);
        /* initialize LED as output */
        LED_INIT;
        /* LEDs off */
        LEDOFF;
        lcd_clrscr();
        lcd_gotoxy(6,1); // print in second line
        lcd_puts("=OK=");
        delay_ms(2000);


        while(1){
                /* display a scroll banner until we
                * get the first command */
                for (i=0;i<BANNERSCROLLEN;i++) {        
                        lcd_clrscr();
                        lcd_gotoxy(0,1); // print in second line
#ifdef FRENCH
                        //as-tu déjà vu
                        lcd_puts(french);
#endif
                        //lcd_putc(0xe4); // ä
                        lcd_gotoxy(0,0); // print in first line
                        rolltext_lcd_p(banner,i);
			LEDOFF;
                        delay_ms(300);
			LEDON;
                        delay_ms(300);
                }
        }

}
